@@ -70,6 +70,7 @@ module Make
         status    : simplex_status;
         debug     : int;
         check_invs: bool;
+        nb_pivots : int ref;
       }
 
     let empty_info =
@@ -92,7 +93,8 @@ module Make
         status    = UNK;
         is_int;
         check_invs;
-        debug
+        debug;
+        nb_pivots = ref 0
       }
 
     let on_integers env = env.is_int
@@ -121,27 +123,36 @@ module Make
 
     let set_min_bound info bnd ex =
       match bnd with
-      | None -> info
+      | None -> info, false
       | Some _new ->
-        if violates_min_bound _new info.mini then info
+        let mini = info.mini in
+        if violates_min_bound _new mini || equals_optimum _new mini then
+          info, false
         else
           let empty_dom = not (consistent_bounds_aux bnd info.maxi) in
-          if violates_min_bound info.value bnd then
-            {info with mini = bnd; min_ex = ex; vstatus = LowerKO; empty_dom}
-          else
-            {info with mini = bnd; min_ex = ex; empty_dom}
+          let i' =
+            if violates_min_bound info.value bnd then
+              {info with mini = bnd; min_ex = ex; vstatus = LowerKO; empty_dom}
+            else
+              {info with mini = bnd; min_ex = ex; empty_dom}
+          in i', true
 
     let set_max_bound info bnd ex =
       match bnd with
-      | None -> info
+      | None -> info, false
       | Some _new ->
-        if violates_max_bound _new info.maxi then info
+        let maxi = info.maxi in
+        if violates_max_bound _new maxi || equals_optimum _new maxi then
+          info, false
         else
           let empty_dom = not (consistent_bounds_aux info.mini bnd) in
-          if violates_max_bound info.value bnd then
-            {info with maxi = bnd; max_ex = ex; vstatus = UpperKO; empty_dom}
-          else
-            {info with maxi = bnd; max_ex = ex; empty_dom}
+          let i' =
+            if violates_max_bound info.value bnd then
+              {info with maxi = bnd; max_ex = ex; vstatus = UpperKO; empty_dom}
+            else
+              {info with maxi = bnd; max_ex = ex; empty_dom}
+          in
+          i', true
 
     let ajust_value_of_non_basic info =
       if info.empty_dom then begin
